# PA164-Text clustering

### Assignment C* - clustering of scientific article abstracts
- Based on a clinically or biologically relevant query of your choice (e.g. `(PD1 OR PDL-1) AND cancer` or `kinases AND neurodegenerative`), gather a corpus of [PubMed](https://pubmed.ncbi.nlm.nih.gov/) abstracts (for instance via [BioPython Entrez API](https://biopython.org/docs/1.75/api/Bio.Entrez.html)).
 - Note that ideally, the query should return a few thousand abstracts at least, and should correspond to a domain with distinct sub-domains.
- Play with two different text preprocessing techniques to get vector representations of the abstracts:
 - One involving a "standard" bag-of-words model via techniques like count vectorisation, TF-IDF scoring, scaling, normalisation, unigrams vs. n-grams and/or dimensionality reduction.
 - One involving a deep learning approach - word and/or document embeddings using [word2vec](https://en.wikipedia.org/wiki/Word2vec), [GloVe](https://en.wikipedia.org/wiki/GloVe_(machine_learning)), [fastText](https://en.wikipedia.org/wiki/FastText) or similar, pre-trained or custom-trained language models (such as [ELMo](https://allennlp.org/elmo)), or a bespoke approach implemented from scratch.
- Use an unsupervised algorithm of your choice to cluster the abstracts based on their associated vectors (the [clustering module](https://scikit-learn.org/stable/modules/clustering.html) of [scikit-learn](https://scikit-learn.org/) offers quite a nice range of applicable techniques).
 - While doing so, focus also on an optimal selection of the cluster size, number, and other relevant hyper-parameters (e.g., via a [grid-search](https://scikit-learn.org/stable/modules/generated/sklearn.model_selection.GridSearchCV.html) API).
 - Note that the choice of a specific technique for getting the vectors from the texts can actually be a hyper-parameter here!
- Use [cluster analysis](https://en.wikipedia.org/wiki/Cluster_analysis) and visualization techniques to interpret the acquired clusters and compare the results of the "classical" and "deep" text preprocessing methods.
- Prepare a 15-minute presentation (with 5 minutes extra for discussion).
 - If you got inspired by existing solutions to this problem, it's perfectly fine, but please say so, give them credit and explain how does your approach differ!
- Present your project to the rest of the class in the last lecture.

#### Choosing ideal vector size
https://aclanthology.org/I17-2006.pdf

#### Evaluation techniques
https://towardsdatascience.com/clustering-documents-with-python-97314ad6a78d

#### Hierarchical document clustering
http://brandonrose.org/clustering
